package cc.toph.simplycompat.compat;

import cc.toph.simplycompat.registry.ConfigRegistry;
import cc.toph.simplycompat.util.ToolMaterials;
import com.simibubi.create.AllItems;
import net.minecraft.core.registries.BuiltInRegistries;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.crafting.Ingredient;
import org.jetbrains.annotations.NotNull;

public enum CreateToolMaterials implements ToolMaterials<CreateToolMaterials> {
    STURDY(
            3,
            1800,
            8.0f,
            3.5f,
            ConfigRegistry.WEAPON_ATTRIBUTES.STURDY,
            14,
            ConfigRegistry.WEAPON_ATTRIBUTES.STURDY_ENABLED,
            AllItems.STURDY_SHEET.getId()

    );

    private final int level;
    private final int uses;
    private final float speed;
    private final float attackDamageBonus;
    private final float damageModifier;
    private final int enchantmentValue;
    private final boolean enabled;
    private final ResourceLocation repairIngredient;

    CreateToolMaterials(
            int level,
            int uses,
            float speed,
            float attackDamageBonus,
            float damageModifier,
            int enchantmentValue,
            boolean enabled,
            ResourceLocation repairIngredient
    ) {
        this.level = level;
        this.uses = uses;
        this.speed = speed;
        this.attackDamageBonus = attackDamageBonus;
        this.enchantmentValue = enchantmentValue;
        this.damageModifier = damageModifier;
        this.enabled = enabled;
        this.repairIngredient = repairIngredient;
    }

    @Override
    public String getName() {
        return this.name().toLowerCase();
    }

    @Override
    public String getIdentifier() {
        return repairIngredient.toString();
    }

    @Override
    public int getUses() {
        return uses;
    }

    @Override
    public float getSpeed() {
        return speed;
    }

    @Override
    public float getAttackDamageBonus() {
        return attackDamageBonus;
    }

    @Override
    public float getDamageModifier() {
        return damageModifier;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public int getEnchantmentValue() {
        return enchantmentValue;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    @Override
    public @NotNull Ingredient getRepairIngredient() {
        return Ingredient.of(BuiltInRegistries.ITEM.get(repairIngredient));
    }

    @Override
    public CreateToolMaterials[] getValues() {
        return values();
    }


}