package cc.toph.simplycompat.item;

import cc.toph.simplycompat.registry.SimplyCompatRegistries;
import cc.toph.simplycompat.util.ToolMaterials;
import cc.toph.simplycompat.util.WeaponType;
import net.sweenus.simplyswords.item.SimplySwordsSwordItem;

/**
 * Extended Class from Simply Swords to store sword type.
 * Storing Sword type will let us avoid all the static mess in registries.
 * This class stores all the data we need from the sword, so we can just
 * retrieve the object from the registries thanks to {@link SimplyCompatRegistries#SWORD_ITEM} and do whatever we need.
 */
public class SimplyCompatSwordItem extends SimplySwordsSwordItem {

    /**
     * The type of the weapon.
     */
    public final WeaponType TYPE;

    /**
     * Constructor for SimplyCompatSwordItem.
     *
     * @param toolMaterial The material of the tool, which some of its properties/stats.
     * @param type         The type of the weapon, which affects its modifiers.
     * @param <E>          The type of the enum that extends ToolMaterials.
     */
    public <E extends Enum<E> & ToolMaterials<E>> SimplyCompatSwordItem(ToolMaterials<E> toolMaterial, WeaponType type) {
        super(
                toolMaterial,
                (int) (toolMaterial.getDamageModifier() + type.getPositiveModifier() - type.getNegativeModifier()),
                type.getAttackSpeed(),
                toolMaterial.getRepairIngredient().toString()
        );

        this.TYPE = type;
    }
}